@@ -62,6 +62,7 @@ gchar *qbwOrientationAction[] = {
 /*******************************************************************************/
 void
 set_portrait(GtkWidget *self, char const *prop, guint32 value){
+  qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V4, "(%p) %s prop,val=[%s,%d]",self, G_STRFUNC, prop, value);
   gdk_property_change(gtk_widget_get_toplevel(self)->window,
                       gdk_atom_intern_static_string (prop),
                       gdk_x11_xatom_to_atom(XA_CARDINAL), 32,
@@ -70,7 +71,7 @@ set_portrait(GtkWidget *self, char const *prop, guint32 value){
 /*******************************************************************************/
 void
 init_portrait(GtkWidget *win){
-
+  qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V4, "(%p) %s",win, G_STRFUNC);
   gtk_widget_realize(win);
   set_portrait(win, "_HILDON_PORTRAIT_MODE_SUPPORT", 1);
   set_portrait(win, "_HILDON_PORTRAIT_MODE_REQUEST", 1);
@@ -78,10 +79,9 @@ init_portrait(GtkWidget *win){
 /*******************************************************************************/
 void
 init_landscape(GtkWidget *win){
-
+  qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V4, "(%p) %s",win, G_STRFUNC);
   gtk_widget_realize(win);
-
-  set_portrait(win, "_HILDON_PORTRAIT_MODE_SUPPORT", 0);
+  set_portrait(win, "_HILDON_PORTRAIT_MODE_SUPPORT", 1);
   set_portrait(win, "_HILDON_PORTRAIT_MODE_REQUEST", 0);
 }
 /*******************************************************************************/
@@ -115,11 +115,12 @@ DBusHandlerResult queen_beecon_orientation_filter_function(DBusConnection *conne
 			klass->orientationFace = g_strdup(orientationFace);
 			qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V4, "(%p) ORIENTATION Mode[%s] Stand[%s] Face[%s] x,y,z(%d,%d,%d)", self, orientationMode, orientationStand, orientationFace, klass->orientationX, klass->orientationY, klass->orientationZ);
 
-            //if (!g_strcmp0(klass->orientationMode, "landscape"))
-            //   init_landscape(GTK_WIDGET(self));
-            //else if (!g_strcmp0(klass->orientationMode, "portrait"))
-            //   init_portrait(GTK_WIDGET(self));
-
+#ifdef NOT_WORKING
+			if (!g_strcmp0(klass->orientationMode, "landscape"))
+               init_landscape(GTK_WIDGET(self));
+            else if (!g_strcmp0(klass->orientationMode, "portrait"))
+               init_portrait(GTK_WIDGET(self));
+#endif //NOT_WORKING
 			queen_beecon_update_content (self, qbwExecReason[QBW_ORIENTATION_MONITOR]);
 	    } else {
 			qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V4, "(%p) DBUS dbus_message_get_args Error [%s]",self, error.message);
