@@ -177,10 +177,10 @@ void queen_beecon_exec_progress_animation(QueenBeecon *self, QbwProgressAnimatio
 		if (self->priv->animationInProgress) {
 			self->priv->animationInProgress = FALSE;
 			gtk_widget_hide(self->priv->beeExecuting_img);
-			if (self->priv->cmdVisibilityPosition    && self->priv->widgetVisible) gtk_widget_show (GTK_WIDGET(self->priv->cmdTitle_lb));
-			if (self->priv->cmdImgVisibilityPosition && self->priv->widgetVisible) gtk_widget_show (GTK_WIDGET(self->priv->cmdTitle_img));
-			if (self->priv->resVisibilityPosition    && self->priv->widgetVisible) gtk_widget_show (GTK_WIDGET(self->priv->cmdResult_lb));
-			if (self->priv->resImgVisibilityPosition && self->priv->widgetVisible) gtk_widget_show (GTK_WIDGET(self->priv->cmdResult_img));
+			if (self->priv->cmdVisibilityPosition    && self->priv->widgetVisible) if (self->priv->cmdTitle_lb) gtk_widget_show (GTK_WIDGET(self->priv->cmdTitle_lb));
+			if (self->priv->cmdImgVisibilityPosition && self->priv->widgetVisible) if (self->priv->cmdTitle_img) gtk_widget_show (GTK_WIDGET(self->priv->cmdTitle_img));
+			if (self->priv->resVisibilityPosition    && self->priv->widgetVisible) if (self->priv->cmdResult_lb) gtk_widget_show (GTK_WIDGET(self->priv->cmdResult_lb));
+			if (self->priv->resImgVisibilityPosition && self->priv->widgetVisible) if (self->priv->cmdResult_img) gtk_widget_show (GTK_WIDGET(self->priv->cmdResult_img));
 		}
 		break;
 
