@@ -20,6 +20,8 @@ of the License, or (at your option) any later version.
 #ifndef _QUEEN_BEECON
 #define _QUEEN_BEECON
 #include <libhildondesktop/libhildondesktop.h>
+#include <location/location-gps-device.h>
+#include <location/location-gpsd-control.h>
 #include <conic.h>
 
 G_BEGIN_DECLS
@@ -54,14 +56,21 @@ struct _QueenBeecon
 
 struct _QueenBeeconClass
 {
-  HDHomePluginItemClass  parent;
-  DBusGConnection *dbus_conn;
-  DBusGProxy	*bus_proxy;
-  gboolean 		dbus_registered;
+  HDHomePluginItemClass	parent;
+  DBusGConnection 		*dbus_conn;
+  DBusGProxy			*bus_proxy;
+  gboolean 				dbus_registered;
   //GMutex 		*config_file_mutex;
 
-  gboolean 		housekeeping;
-  gboolean 		settingsOn;
+  gboolean 				housekeeping;
+  gboolean 				settingsOn;
+  gchar 				*orientationMode;
+  gchar 				*orientationStand;
+  gchar 				*orientationFace;
+  gint					orientationX;
+  gint					orientationY;
+  gint					orientationZ;
+  guint					GPSrelayEnableTimer;
 
   // Signal functions Declarations
   void (*queen_beecon_dbus_sig_content_updated) (QueenBeecon *self, gint exitCode);
@@ -96,11 +105,29 @@ GType queen_beecon_get_type (void);
 #define NETWORK__PASSTHROUGH 3
 
 #define SIZE_WIDTH_ALL 800
-#define SIZE_HEIGHT_ALL 420//AP3
+#define SIZE_HEIGHT_ALL 424//AP3
 #define SIZE_BEECON_RATIO 2 * 1.7//AP3
 
 #define QBW_PROGRESS_ANIMATION_FRAMES_MAX 30
 
+typedef enum {
+	QBW_SUBSYSTEM_ALL_OK       = 0,
+	QBW_SUBSYSTEM_TIMER        = 1 << 0,
+	QBW_SUBSYSTEM_DBUS_MONITOR = 1 << 1,
+	QBW_SUBSYSTEM_LOCATION     = 1 << 2,
+	QBW_SUBSYSTEM_ORIENTATION  = 1 << 3,
+	QBW_SUBSYSTEM_CONNECTION   = 1 << 4,
+	QBW_SUBSYSTEM_ALL          = 0xFFFF
+} QbwOperationalSubsystems;
+
+typedef enum {
+	QBW_SUBSYSTEM_INIT,
+	QBW_SUBSYSTEM_DISABLE,
+	QBW_SUBSYSTEM_ENABLE,
+	QBW_SUBSYSTEM_RESTART,
+	QBW_SUBSYSTEM_DEINIT
+} QbwOperationalSubsystemsAction;
+
 enum {
 	SIG_CONTENT_UPDATED,
 	LAST_SIGNAL
@@ -119,6 +146,8 @@ enum {
 	QBW_DBUS_WAKEUP,
 	QBW_DBUS_UPDATE_CONTENT,
 	QBW_DBUS_EXEC,
+	QBW_ORIENTATION_MONITOR,
+	QBW_LOCATION_MONITOR_FIX,
 	QBW_DBUS_MONITOR,
 	QBW_LAST
 };
@@ -141,6 +170,9 @@ void queen_beecon_update_content_layout (QueenBeecon *self);
 void queen_beecon_draw_canvas(GtkWidget *widget);
 gboolean queen_beecon_expose_event (GtkWidget *widget, GdkEventExpose *event);
 gboolean queen_beecon_button_release_exec (QueenBeecon *self);
+QbwOperationalSubsystems queen_beecon_op_subsystems_manager(QueenBeecon *self, QbwOperationalSubsystemsAction action, QbwOperationalSubsystems subsystems);
+gchar *queen_beecon_op_subsystems_error_message(QbwOperationalSubsystems subsystems);
+GtkWidget *queen_beecon_picker_button_no_yes_create(const gchar *title, gboolean value, GtkWidget *box, gboolean expand, gboolean fill);
 
 //Dialogs prototypes:
 gboolean queen_beecon_edit_add_dialog ( QueenBeecon *self, gboolean new, gint curr);
@@ -190,6 +222,7 @@ struct _QueenBeeconPrivate
 		gboolean 		hideClickCanvas;
 		gboolean 		updOnStartup;
 		gboolean 		updOnClick;
+		gboolean 		multiClick;
 		gboolean 		isPressed;
 		gboolean 		clicksCount;
 		guint 			clicksTimerID;
@@ -201,6 +234,8 @@ struct _QueenBeeconPrivate
 		guint 			updNeworkPolicy;
 		gboolean 		updOnSight;
 		gboolean 		qbwOnSight;
+		gboolean 		updOnOrientation;
+
 		gboolean		startupAnimation;
 		gboolean		animationInProgress;
 
@@ -275,6 +310,7 @@ struct _QueenBeeconPrivate
 		guint 			resImgVisibilityPosition;//AP3
 		guint			resTextAngle;
 		guint 			resJustify;//AP3
+		gboolean		resWrapLongLines;
 		gchar			*resExtFont;
 		gint 			resFontName;//AP1
 		gdouble 		resFontSize;//AP1
@@ -299,6 +335,7 @@ struct _QueenBeeconPrivate
 		gchar			*updOnDBUSMatchRule; //(0=system/1=session)
 		GString 		*dbusVerboseMsg;
 		gboolean		execDBUSMatchInProgress;
+		gboolean		DBUSmonitorONOFF;
 
 		//exec input/output
 		gchar			*execAuxOutput;
@@ -325,11 +362,24 @@ struct _QueenBeeconPrivate
 	    /* Timeout source id */
 	    gint 			timeout_id;
 
+		/* Orientation info */
+		gboolean			orientationONOFF;
+
+		/* GPSLocation info */
+		LocationGPSDControl	*GPScontrol;
+		LocationGPSDevice	*GPSdevice;
+		gint				GPSsettings;
+		gboolean			GPSstatusONOFF;
+		gchar				*GPSfixinfo;
+
 		//network connection query ptr
 		ConIcConnection	*connection;
 		gboolean 		isConnected;
+		gboolean		connectedONOFF;
+		gchar 			*disconnecting_iap;
 
 		//Advanced Dialog data
+		gboolean 		instanceUpdateOK;
 		gboolean 		instanceImportOK;
 		GtkTextBuffer 	*importExportBuffer, *cmdTestDriveBuffer, *cmdOutputBuffer; // Buffers for advanced dialog box
 		GtkWidget 		*commandPicker;
@@ -476,6 +526,8 @@ struct _QueenBeeconPrivate
 		GtkWidget *resTextAngleSelectorW;
 		GtkWidget *resJustifyW;
 		GtkWidget *resJustifySelectorW;
+		GtkWidget *resWrapW;
+		GtkWidget *resWrapSelectorW;
 
 		//DBUS Progress Animation
 		GtkWidget *progrAnimLabelW;
@@ -506,17 +558,22 @@ struct _QueenBeeconPrivate
 		GtkWidget *rememberMeW;
 
 		GtkWidget *updPolicyLabelW;
-		GtkWidget *updBoxW;
+		GtkWidget *updBox1W;
+		GtkWidget *updBox2W;
+		GtkWidget *updBox3W;
 		GtkWidget *checkBtStartupW;
 		GtkWidget *checkBtClickW;
+		GtkWidget *checkBtMClickW;
+		GtkWidget *checkBtOrientationW;
 		GtkWidget *checkBtDesktopW;
-		GtkWidget *intervalNetBoxW;
 		GtkWidget *intervalSelectorW;
 		GtkWidget *intervalSelBtW;
 		GtkWidget *intervalCustomEntryW;
 		GtkWidget *updIntervalLabelW;
 		GtkWidget *networkPolicySelW;
 		GtkWidget *networkPolBtW;
+		GtkWidget *locationSelW;
+		GtkWidget *locationPolBtW;
 		GtkWidget *networkPolBtHelpW;
 		GtkWidget *checkBtSightW;
 		GtkWidget *goProW;
